"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logEnvParseError = exports.logPackumentResolveError = exports.logManifestSaveError = exports.logManifestLoadError = void 0;
const common_errors_1 = require("../common-errors");
const packument_1 = require("../domain/packument");
const wsl_1 = require("../io/wsl");
const process_1 = require("../utils/process");
const upm_config_io_1 = require("../io/upm-config-io");
const common_errors_2 = require("../io/common-errors");
const string_parsing_1 = require("../utils/string-parsing");
/**
 * Logs a {@link ManifestLoadError} to the console.
 */
function logManifestLoadError(log, error) {
    const reason = error instanceof common_errors_2.FileMissingError
        ? `it could not be found at "${error.path}"`
        : error instanceof common_errors_2.GenericIOError
            ? "a file-system interaction failed"
            : error instanceof string_parsing_1.StringFormatError
                ? "the manifest file did not contain valid json"
                : "the manifest file did not contain a valid project manifest";
    const prefix = "manifest";
    const errorMessage = `Could not load project manifest because ${reason}.`;
    log.error(prefix, errorMessage);
    // TODO: Print fix suggestions
}
exports.logManifestLoadError = logManifestLoadError;
/**
 * Logs a {@link ManifestWriteError} to the console.
 */
function logManifestSaveError(log, error) {
    const prefix = "manifest";
    log.error(prefix, "can not write manifest json file");
    log.error(prefix, error.message);
}
exports.logManifestSaveError = logManifestSaveError;
/**
 * Logs a {@link PackumentVersionResolveError} to the console.
 */
function logPackumentResolveError(log, packageName, error) {
    if (error instanceof common_errors_1.PackumentNotFoundError)
        log.error("404", `package not found: ${packageName}`);
    else if (error instanceof packument_1.VersionNotFoundError) {
        const versionList = [...error.availableVersions].reverse().join(", ");
        log.warn("404", `version ${error.requestedVersion} is not a valid choice of: ${versionList}`);
    }
}
exports.logPackumentResolveError = logPackumentResolveError;
/**
 * Logs a {@link EnvParseError} to a logger.
 */
function logEnvParseError(log, error) {
    // TODO: Formulate more specific error messages.
    const reason = error instanceof wsl_1.NoWslError
        ? "you attempted to use wsl even though you are not running openupm inside wsl"
        : error instanceof common_errors_2.FileMissingError
            ? `the projects version file (ProjectVersion.txt) could not be found at "${error.path}"`
            : error instanceof common_errors_2.GenericIOError
                ? `a file-system interaction failed`
                : error instanceof process_1.ChildProcessError
                    ? "a required child process failed"
                    : error instanceof common_errors_1.FileParseError
                        ? `the project version file (ProjectVersion.txt) has an invalid structure`
                        : error instanceof upm_config_io_1.RequiredEnvMissingError
                            ? `none of the following environment variables were set: ${error.keyNames.join(", ")}`
                            : `a string was malformed. Expected to be ${error.formatName}`;
    const errorMessage = `environment information could not be parsed because ${reason}.`;
    log.error("", errorMessage);
    // TODO: Suggest actions user might take in order to fix the problem.
}
exports.logEnvParseError = logEnvParseError;
//# sourceMappingURL=error-logging.js.map