"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeProjectManifestWriter = exports.makeProjectManifestLoader = exports.makeProjectManifestParseError = exports.makeProjectManifestMissingError = exports.manifestPathFor = void 0;
const project_manifest_1 = require("../domain/project-manifest");
const path_1 = __importDefault(require("path"));
const ts_results_es_1 = require("ts-results-es");
const string_parsing_1 = require("../utils/string-parsing");
const common_errors_1 = require("../common-errors");
const common_errors_2 = require("./common-errors");
/**
 * Determines the path to the package manifest based on the project
 * directory.
 * @param projectPath The root path of the Unity project.
 */
function manifestPathFor(projectPath) {
    return path_1.default.join(projectPath, "Packages/manifest.json");
}
exports.manifestPathFor = manifestPathFor;
/**
 * Makes a new {@link ProjectManifestMissingError}.
 * @param filePath The path that was searched.
 */
function makeProjectManifestMissingError(filePath) {
    return new common_errors_2.FileMissingError("ProjectManifest", filePath);
}
exports.makeProjectManifestMissingError = makeProjectManifestMissingError;
/**
 * Makes a {@link ProjectManifestParseError} object.
 * @param filePath The path of the file.
 */
function makeProjectManifestParseError(filePath) {
    return new common_errors_1.FileParseError(filePath, "ProjectManifest");
}
exports.makeProjectManifestParseError = makeProjectManifestParseError;
/**
 * Makes a {@link LoadProjectManifest} function.
 */
function makeProjectManifestLoader(readFile) {
    return (projectPath) => {
        const manifestPath = manifestPathFor(projectPath);
        return readFile(manifestPath)
            .mapErr((error) => error.code === "ENOENT"
            ? makeProjectManifestMissingError(manifestPath)
            : new common_errors_2.GenericIOError())
            .andThen(string_parsing_1.tryParseJson)
            .andThen((json) => typeof json === "object"
            ? // TODO: Actually validate the json structure
                (0, ts_results_es_1.Ok)(json)
            : (0, ts_results_es_1.Err)(makeProjectManifestParseError(manifestPath)));
    };
}
exports.makeProjectManifestLoader = makeProjectManifestLoader;
/**
 * Makes a {@link WriteProjectManifest} function.
 */
function makeProjectManifestWriter(writeFile) {
    return (projectPath, manifest) => {
        const manifestPath = manifestPathFor(projectPath);
        manifest = (0, project_manifest_1.pruneManifest)(manifest);
        const json = JSON.stringify(manifest, null, 2);
        return writeFile(manifestPath, json).mapErr(() => new common_errors_2.GenericIOError());
    };
}
exports.makeProjectManifestWriter = makeProjectManifestWriter;
//# sourceMappingURL=project-manifest-io.js.map